pub async fn lookup_host<T>(host: T) -> Result<impl Iterator<Item = SocketAddr>>where
T: ToSocketAddrs,Expand description
Performs a DNS resolution.
Must be called from within a turmoil simulation context.
pub async fn lookup_host<T>(host: T) -> Result<impl Iterator<Item = SocketAddr>>where
T: ToSocketAddrs,Performs a DNS resolution.
Must be called from within a turmoil simulation context.