pub fn since_epoch() -> Option<Duration>Expand description
The logical duration from [UNIX_EPOCH] until now.
On creation the simulation picks a SystemTime and calculates the
duration since the epoch. Each run() invocation moves logical time
forward the configured tick duration.
Will return None if the duration is not available, typically because there is no currently executing host or world.